# media_editing

# Markdown_to_HTML.py

This script recursively converts Markdown files at a specified directory to HTML files, with options to include table of contents and to specify a CSS style.

# images_to_video.py

This script converts a list of image files to a video with the options of specifying the image extension, a soundtrack file, an output filename and framerate

# vidgif.py

This script converts a video to an animated GIF.
